diff --git a/README.md b/README.md
index b9fd5328..12fbe9e3 100644
--- a/README.md
+++ b/README.md
@@ -3,7 +3,8 @@ HeliBoard is a privacy-conscious and customizable open-source keyboard, based on
Does not use internet permission, and thus is 100% offline.
[
](https://f-droid.org/packages/helium314.keyboard/)
-[
](https://github.com/Helium314/HeliBoard/releases/latest)
+[
](https://github.com/Helium314/HeliBoard/releases/latest)
+[
](https://apt.izzysoft.de/fdroid/index/apk/helium314.keyboard)
## Table of Contents
diff --git a/release.py b/release.py
index 5a9b58a2..2948fcc9 100755
--- a/release.py
+++ b/release.py
@@ -18,10 +18,11 @@ def update_translations():
url = "https://translate.codeberg.org/download/heliboard/?format=zip"
zip_file_name = "translations.zip"
urlretrieve(url, zip_file_name)
# extract all in heliboard/heliboard/app/src/main/res
with zipfile.ZipFile(zip_file_name, "r") as f:
for file in f.filelist:
- if not file.filename.startswith("heliboard/heliboard/app/src/main/res"):
+ if not file.filename.startswith("heliboard/heliboard/app/src/main/res")\
+ and not file.filename.startswith("heliboard/heliboard/fastlane/metadata"):
continue
file.filename = file.filename.replace("heliboard/heliboard/", "")
f.extract(file)
@@ -40,7 +41,7 @@ def update_dict_list():
# gradle = "gradlew" # Linux
# gradle = "gradlew.bat" # Windows
gradle = "../../builder/realgradle.sh" # weird path for historic reasons
- result = subprocess.run([gradle, ":tools:make-dict-list:makeDictList"])
+ result = subprocess.run([gradle, ":tools:make-dict-list:makeDictList"]) # todo: replace with python code
assert result.returncode == 0
@@ -18,10 +18,11 @@ def update_translations():
zip_file_name = "translations.zip"
urlretrieve(url, zip_file_name)
- # extract all in heliboard/heliboard/app/src/main/res
+ # extract all in heliboard/heliboard/app/src/main/res and heliboard/heliboard/fastlane/metadata
with zipfile.ZipFile(zip_file_name, "r") as f:
for file in f.filelist: